==> apache-cxf-3.6.4-src.zip: apache-cxf-3.6.4-src/systests/uncategorized/src/test/java/org/apache/cxf/cxf1332/Cxf1332Impl.java <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements. See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership. The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package org.apache.cxf.cxf1332;

import javax.jws.WebMethod;
import javax.jws.WebParam;
import javax.jws.WebResult;
import javax.jws.WebService;

/**
 *
 */
@WebService(targetNamespace = "urn:org.apache.cxf.1332")
public class Cxf1332Impl implements Cxf1332 {
    private static String[] lastStrings;

    /** {@inheritDoc}*/
    @WebMethod(operationName = "SendData", action = "")
    @WebResult(name = "result", targetNamespace = "urn:org.apache.cxf.1332.result")
    public String hostSendData(@WebParam(name = "params", targetNamespace = "") String[] strs) {
        lastStrings = strs;
        return "Bloop";
    }

    public static String[] getLastStrings() {
        return lastStrings;
    }
}

==> apache-cxf-4.0.8-src.zip: apache-cxf-4.0.8-src/systests/uncategorized/src/test/java/org/apache/cxf/cxf1332/Cxf1332Impl.java <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements. See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership. The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package org.apache.cxf.cxf1332;

import jakarta.jws.WebMethod;
import jakarta.jws.WebParam;
import jakarta.jws.WebResult;
import jakarta.jws.WebService;

/**
 *
 */
@WebService(targetNamespace = "urn:org.apache.cxf.1332")
public class Cxf1332Impl implements Cxf1332 {
    private static String[] lastStrings;

    /** {@inheritDoc}*/
    @WebMethod(operationName = "SendData", action = "")
    @WebResult(name = "result", targetNamespace = "urn:org.apache.cxf.1332.result")
    public String hostSendData(@WebParam(name = "params", targetNamespace = "") String[] strs) {
        lastStrings = strs;
        return "Bloop";
    }

    public static String[] getLastStrings() {
        return lastStrings;
    }
}
